==> compmec_section-0.2.0.tar.gz: compmec_section-0.2.0/README.md <==
[![Documentation Status][docs-img]][docs-url]
[![Build Status][build-img]][build-url]
[![Lint with Black][lintblack-img]][lintblack-url]
[![Code Coverage][coverage-img]][coverage-url]

[![PyPI Version][pypi-img]][pypi-url]
[![Python Versions][pyversions-img]][pyversions-url]
[![License: MIT][license-img]][license-url]

![compmec-section logo](docs/source/img/logo.svg)

A python package for bidimensional geometric sections boolean manipulation.


### Installation:

This library is available in [PyPI][pypi-url]. To install it

```
$ pip install compmec-section
```

For more details, refer to the [documentation][docs-url].

### Documentation

The documentation can be found at [compmec-section.readthedocs.io][docs-url]


### Contribute

Please see [How to contribute][contribute-url] or if you find any bug, use the [Issues][issues-url].

<!-- Badges: -->

[lintblack-img]: https://github.com/compmec/section/actions/workflows/black.yaml/badge.svg
[lintblack-url]: https://github.com/compmec/section/actions/workflows/black.yaml
[docs-img]: https://readthedocs.org/projects/compmec-section/badge/?version=latest
[docs-url]: https://compmec-section.readthedocs.io/en/latest/?badge=latest
[pypi-img]: https://img.shields.io/pypi/v/compmec-section
[pypi-url]: https://pypi.org/project/compmec-section/
[build-img]: https://github.com/compmec/section/actions/workflows/build.yaml/badge.svg
[build-url]: https://github.com/compmec/section/actions/workflows/build.yaml
[coverage-img]: https://codecov.io/gh/compmec/section/branch/main/graph/badge.svg?token=vfGMPe9W3I
[coverage-url]: https://codecov.io/gh/compmec/section
[pyversions-img]: https://img.shields.io/pypi/pyversions/compmec-section.svg?style=flat-square
[pyversions-url]: https://pypi.org/project/compmec-section/
[license-img]: https://img.shields.io/pypi/l/ansicolortags.svg
[license-url]: https://github.com/compmec/section/blob/main/LICENSE.md
[pypi-url]: https://pypi.org/project/compmec-section/
[issues-url]: https://github.com/compmec/section/issues
[contribute-url]: https://github.com/compmec/section/discussions/2

==> compmec_section-0.3.0.tar.gz: compmec_section-0.3.0/README.md <==
[![Documentation Status][docs-img]][docs-url]
[![Build Status][build-img]][build-url]
[![Lint with Black][lintblack-img]][lintblack-url]
[![Code Coverage][coverage-img]][coverage-url]

[![PyPI Version][pypi-img]][pypi-url]
[![Python Versions][pyversions-img]][pyversions-url]
[![License: MIT][license-img]][license-url]

![compmec-section logo](docs/source/img/logo.svg)

A python package for analysis of beam sections by using Boundary Element Method.

### Installation:

This library is available in [PyPI][pypi-url]. To install it

```
$ pip install compmec-section
```

For more details, refer to the [documentation][docs-url].

### Documentation

The documentation can be found at [compmec-section.readthedocs.io][docs-url]


### Contribute

Please see [How to contribute][contribute-url] or if you find any bug, use the [Issues][issues-url].

<!-- Badges: -->

[lintblack-img]: https://github.com/compmec/section/actions/workflows/black.yaml/badge.svg
[lintblack-url]: https://github.com/compmec/section/actions/workflows/black.yaml
[docs-img]: https://readthedocs.org/projects/compmec-section/badge/?version=latest
[docs-url]: https://compmec-section.readthedocs.io/en/latest/?badge=latest
[pypi-img]: https://img.shields.io/pypi/v/compmec-section
[pypi-url]: https://pypi.org/project/compmec-section/
[build-img]: https://github.com/compmec/section/actions/workflows/build.yaml/badge.svg
[build-url]: https://github.com/compmec/section/actions/workflows/build.yaml
[coverage-img]: https://codecov.io/gh/compmec/section/branch/main/graph/badge.svg?token=vfGMPe9W3I
[coverage-url]: https://codecov.io/gh/compmec/section
[pyversions-img]: https://img.shields.io/pypi/pyversions/compmec-section.svg?style=flat-square
[pyversions-url]: https://pypi.org/project/compmec-section/
[license-img]: https://img.shields.io/pypi/l/ansicolortags.svg
[license-url]: https://github.com/compmec/section/blob/main/LICENSE.md
[pypi-url]: https://pypi.org/project/compmec-section/
[issues-url]: https://github.com/compmec/section/issues
[contribute-url]: https://github.com/compmec/section/discussions/2
